| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.Audio.Transcriptions
Contents
Description
/v1/audio/transcriptions
To simplify things, this only supports the verbose_json response format
and also only supports the segment granularity
Synopsis
- data CreateTranscription = CreateTranscription {}
- _CreateTranscription :: CreateTranscription
- data TranscriptionObject = TranscriptionObject {}
- data Segment = Segment {
- id :: Integer
- seek :: Integer
- start :: Double
- end :: Double
- text :: Text
- tokens :: Vector Word
- temperature :: Double
- avg_logprob :: Double
- compression_ratio :: Double
- no_speech_prob :: Double
- type API = "transcriptions" :> (MultipartForm Tmp CreateTranscription :> Post '[JSON] TranscriptionObject)
Main types
data CreateTranscription Source #
Request body for /v1/audio/transcriptions
Constructors
| CreateTranscription | |
Instances
data TranscriptionObject Source #
Represents a verbose json transcription response returned by model, based on the provided input.
Constructors
| TranscriptionObject | |
Instances
| FromJSON TranscriptionObject Source # | |||||
Defined in OpenAI.V1.Audio.Transcriptions Methods parseJSON :: Value -> Parser TranscriptionObject # parseJSONList :: Value -> Parser [TranscriptionObject] # | |||||
| ToJSON TranscriptionObject Source # | |||||
Defined in OpenAI.V1.Audio.Transcriptions Methods toJSON :: TranscriptionObject -> Value # toEncoding :: TranscriptionObject -> Encoding # toJSONList :: [TranscriptionObject] -> Value # toEncodingList :: [TranscriptionObject] -> Encoding # omitField :: TranscriptionObject -> Bool # | |||||
| Generic TranscriptionObject Source # | |||||
Defined in OpenAI.V1.Audio.Transcriptions Associated Types
Methods from :: TranscriptionObject -> Rep TranscriptionObject x # to :: Rep TranscriptionObject x -> TranscriptionObject # | |||||
| Show TranscriptionObject Source # | |||||
Defined in OpenAI.V1.Audio.Transcriptions Methods showsPrec :: Int -> TranscriptionObject -> ShowS # show :: TranscriptionObject -> String # showList :: [TranscriptionObject] -> ShowS # | |||||
| type Rep TranscriptionObject Source # | |||||
Defined in OpenAI.V1.Audio.Transcriptions type Rep TranscriptionObject = D1 ('MetaData "TranscriptionObject" "OpenAI.V1.Audio.Transcriptions" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "TranscriptionObject" 'PrefixI 'True) ((S1 ('MetaSel ('Just "language") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "duration") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Double))) :*: (S1 ('MetaSel ('Just "text") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text) :*: S1 ('MetaSel ('Just "segments") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Vector Segment))))) | |||||
Other types
Segment of the transcribed text and its corresponding details
Constructors
| Segment | |
Fields
| |
Instances
| FromJSON Segment Source # | |||||
Defined in OpenAI.V1.Audio.Transcriptions | |||||
| ToJSON Segment Source # | |||||
| Generic Segment Source # | |||||
Defined in OpenAI.V1.Audio.Transcriptions Associated Types
| |||||
| Show Segment Source # | |||||
| type Rep Segment Source # | |||||
Defined in OpenAI.V1.Audio.Transcriptions type Rep Segment = D1 ('MetaData "Segment" "OpenAI.V1.Audio.Transcriptions" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "Segment" 'PrefixI 'True) (((S1 ('MetaSel ('Just "id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Integer) :*: S1 ('MetaSel ('Just "seek") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Integer)) :*: (S1 ('MetaSel ('Just "start") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double) :*: (S1 ('MetaSel ('Just "end") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double) :*: S1 ('MetaSel ('Just "text") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)))) :*: ((S1 ('MetaSel ('Just "tokens") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Vector Word)) :*: S1 ('MetaSel ('Just "temperature") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double)) :*: (S1 ('MetaSel ('Just "avg_logprob") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double) :*: (S1 ('MetaSel ('Just "compression_ratio") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double) :*: S1 ('MetaSel ('Just "no_speech_prob") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double)))))) | |||||
Servant
type API = "transcriptions" :> (MultipartForm Tmp CreateTranscription :> Post '[JSON] TranscriptionObject) Source #
Servant API