| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.AutoOr
Contents
Description
The AutoOr type constructor
Types
A type that can also be the string "auto"
| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.AutoOr
Contents
Description
The AutoOr type constructor
A type that can also be the string "auto"