openai-2.2.1: Servant bindings to OpenAI
Safe HaskellNone
LanguageHaskell2010

OpenAI.V1.Error

Contents

Description

Error information

Synopsis

Types

data Error Source #

More information on the cause of the failure.

NOTE: OpenAPI API's says that the code and message fields are required, but in practice the Error record can be present with all fields omitted, so they are all marked optional (Maybe) here

Constructors

Error 

Instances

Instances details
FromJSON Error Source # 
Instance details

Defined in OpenAI.V1.Error

ToJSON Error Source # 
Instance details

Defined in OpenAI.V1.Error

Generic Error Source # 
Instance details

Defined in OpenAI.V1.Error

Associated Types

type Rep Error 
Instance details

Defined in OpenAI.V1.Error

Methods

from :: Error -> Rep Error x #

to :: Rep Error x -> Error #

Show Error Source # 
Instance details

Defined in OpenAI.V1.Error

Methods

showsPrec :: Int -> Error -> ShowS #

show :: Error -> String #

showList :: [Error] -> ShowS #

type Rep Error Source # 
Instance details

Defined in OpenAI.V1.Error