| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.ListOf
Contents
Description
The ListOf type constructor
Types
Whenever OpenAI says that an API endpoint returns a list of items, what they actually mean is that it returns that list wrapped inside of the following object
Instances
| FromJSON a => FromJSON (ListOf a) Source # | |||||
Defined in OpenAI.V1.ListOf | |||||
| ToJSON a => ToJSON (ListOf a) Source # | |||||
| Generic (ListOf a) Source # | |||||
Defined in OpenAI.V1.ListOf Associated Types
| |||||
| Show a => Show (ListOf a) Source # | |||||
| type Rep (ListOf a) Source # | |||||
Defined in OpenAI.V1.ListOf | |||||