| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.Message
Contents
Description
The Message type
Synopsis
- data Message
- data ImageFile = ImageFile {}
- data ImageURL = ImageURL {}
- data Content text
- = Image_File { }
- | Image_URL { }
- | Text {
- text :: text
- data Attachment = Attachment {}
Main types
A message
Instances
Other types
References an image File in the content of a message
Instances
| FromJSON ImageFile Source # | |||||
Defined in OpenAI.V1.Message | |||||
| ToJSON ImageFile Source # | |||||
| Generic ImageFile Source # | |||||
Defined in OpenAI.V1.Message Associated Types
| |||||
| Show ImageFile Source # | |||||
| type Rep ImageFile Source # | |||||
Defined in OpenAI.V1.Message type Rep ImageFile = D1 ('MetaData "ImageFile" "OpenAI.V1.Message" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "ImageFile" 'PrefixI 'True) (S1 ('MetaSel ('Just "file_id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 FileID) :*: S1 ('MetaSel ('Just "detail") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (AutoOr Text))))) | |||||
References an image URL in the content of a message
Instances
| FromJSON ImageURL Source # | |||||
Defined in OpenAI.V1.Message | |||||
| ToJSON ImageURL Source # | |||||
| Generic ImageURL Source # | |||||
Defined in OpenAI.V1.Message Associated Types
| |||||
| Show ImageURL Source # | |||||
| type Rep ImageURL Source # | |||||
Defined in OpenAI.V1.Message type Rep ImageURL = D1 ('MetaData "ImageURL" "OpenAI.V1.Message" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "ImageURL" 'PrefixI 'True) (S1 ('MetaSel ('Just "image_url") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text) :*: S1 ('MetaSel ('Just "detail") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (AutoOr Text))))) | |||||
Message content
Constructors
| Image_File | |
Fields | |
| Image_URL | |
| Text | |
Fields
| |
Instances
| FromJSON text => FromJSON (Content text) Source # | |||||
Defined in OpenAI.V1.Message | |||||
| ToJSON text => ToJSON (Content text) Source # | |||||
| IsString text => IsString (Content text) Source # | |||||
Defined in OpenAI.V1.Message Methods fromString :: String -> Content text # | |||||
| Generic (Content text) Source # | |||||
Defined in OpenAI.V1.Message Associated Types
| |||||
| Show text => Show (Content text) Source # | |||||
| type Rep (Content text) Source # | |||||
Defined in OpenAI.V1.Message type Rep (Content text) = D1 ('MetaData "Content" "OpenAI.V1.Message" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "Image_File" 'PrefixI 'True) (S1 ('MetaSel ('Just "image_file") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 ImageFile)) :+: (C1 ('MetaCons "Image_URL" 'PrefixI 'True) (S1 ('MetaSel ('Just "image_url") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 ImageURL)) :+: C1 ('MetaCons "Text" 'PrefixI 'True) (S1 ('MetaSel ('Just "text") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 text)))) | |||||
data Attachment Source #
A file attached to the message, and the tools it should be added to
Instances
| FromJSON Attachment Source # | |||||
Defined in OpenAI.V1.Message | |||||
| ToJSON Attachment Source # | |||||
Defined in OpenAI.V1.Message Methods toJSON :: Attachment -> Value # toEncoding :: Attachment -> Encoding # toJSONList :: [Attachment] -> Value # toEncodingList :: [Attachment] -> Encoding # omitField :: Attachment -> Bool # | |||||
| Generic Attachment Source # | |||||
Defined in OpenAI.V1.Message Associated Types
| |||||
| Show Attachment Source # | |||||
Defined in OpenAI.V1.Message Methods showsPrec :: Int -> Attachment -> ShowS # show :: Attachment -> String # showList :: [Attachment] -> ShowS # | |||||
| type Rep Attachment Source # | |||||
Defined in OpenAI.V1.Message type Rep Attachment = D1 ('MetaData "Attachment" "OpenAI.V1.Message" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "Attachment" 'PrefixI 'True) (S1 ('MetaSel ('Just "file_id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 FileID) :*: S1 ('MetaSel ('Just "tools") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Vector Tool))))) | |||||