| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.ResponseFormat
Contents
Description
The ResponseFormat type
Synopsis
- data ResponseFormat
- data JSONSchema = JSONSchema {}
Types
data ResponseFormat Source #
An object specifying the format that the model must output
Constructors
| ResponseFormat_Text | |
| JSON_Object | |
| JSON_Schema | |
Fields | |
Instances
data JSONSchema Source #
Setting to { "type": "json_schema", "json_schema": {...} } enables Structured Outputs which ensures the model will match your supplied JSON schema. Learn more in the Structured Outputs guide
Constructors
| JSONSchema | |
Instances
| FromJSON JSONSchema Source # | |||||
Defined in OpenAI.V1.ResponseFormat | |||||
| ToJSON JSONSchema Source # | |||||
Defined in OpenAI.V1.ResponseFormat Methods toJSON :: JSONSchema -> Value # toEncoding :: JSONSchema -> Encoding # toJSONList :: [JSONSchema] -> Value # toEncodingList :: [JSONSchema] -> Encoding # omitField :: JSONSchema -> Bool # | |||||
| Generic JSONSchema Source # | |||||
Defined in OpenAI.V1.ResponseFormat Associated Types
| |||||
| Show JSONSchema Source # | |||||
Defined in OpenAI.V1.ResponseFormat Methods showsPrec :: Int -> JSONSchema -> ShowS # show :: JSONSchema -> String # showList :: [JSONSchema] -> ShowS # | |||||
| type Rep JSONSchema Source # | |||||
Defined in OpenAI.V1.ResponseFormat type Rep JSONSchema = D1 ('MetaData "JSONSchema" "OpenAI.V1.ResponseFormat" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "JSONSchema" 'PrefixI 'True) ((S1 ('MetaSel ('Just "description") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "name") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)) :*: (S1 ('MetaSel ('Just "schema") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Value)) :*: S1 ('MetaSel ('Just "strict") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Bool))))) | |||||