| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.Threads.Runs
Contents
Description
/v1/threads/:thread_id/runs
Synopsis
- newtype RunID = RunID {}
- data CreateRun = CreateRun {
- assistant_id :: AssistantID
- model :: Maybe Model
- instructions :: Maybe Text
- additional_instructions :: Maybe Text
- additional_messages :: Maybe (Vector Message)
- tools :: Maybe (Vector Tool)
- metadata :: Maybe (Map Text Text)
- temperature :: Maybe Double
- top_p :: Maybe Double
- max_prompt_tokens :: Maybe Natural
- max_completion_tokens :: Maybe Natural
- truncation_strategy :: Maybe TruncationStrategy
- tool_choice :: Maybe ToolChoice
- parallel_tool_calls :: Maybe Bool
- response_format :: Maybe (AutoOr ResponseFormat)
- _CreateRun :: CreateRun
- data CreateThreadAndRun = CreateThreadAndRun {
- assistant_id :: AssistantID
- thread :: Maybe Thread
- model :: Maybe Model
- instructions :: Maybe Text
- tools :: Maybe (Vector Tool)
- toolResources :: Maybe ToolResources
- metadata :: Maybe (Map Text Text)
- temperature :: Maybe Double
- top_p :: Maybe Double
- max_prompt_tokens :: Maybe Natural
- max_completion_tokens :: Maybe Natural
- truncation_strategy :: Maybe TruncationStrategy
- tool_choice :: Maybe ToolChoice
- parallel_tool_calls :: Maybe Bool
- response_format :: Maybe (AutoOr ResponseFormat)
- _CreateThreadAndRun :: CreateThreadAndRun
- data ModifyRun = ModifyRun {}
- _ModifyRun :: ModifyRun
- data SubmitToolOutputsToRun = SubmitToolOutputsToRun {
- tool_outputs :: Vector ToolOutput
- _SubmitToolOutputsToRun :: SubmitToolOutputsToRun
- data RunObject = RunObject {
- id :: RunID
- object :: Text
- created_at :: POSIXTime
- thread_id :: ThreadID
- assistant_id :: AssistantID
- status :: Status
- required_action :: Maybe RequiredAction
- last_error :: Maybe Error
- expires_at :: Maybe POSIXTime
- started_at :: Maybe POSIXTime
- cancelled_at :: Maybe POSIXTime
- failed_at :: Maybe POSIXTime
- completed_at :: Maybe POSIXTime
- incomplete_details :: Maybe IncompleteDetails
- model :: Model
- instructions :: Maybe Text
- tools :: Vector Tool
- metadata :: Map Text Text
- usage :: Maybe (Usage (Maybe CompletionTokensDetails) (Maybe PromptTokensDetails))
- temperature :: Maybe Double
- top_p :: Maybe Double
- max_prompt_tokens :: Maybe Natural
- max_completion_tokens :: Maybe Natural
- truncation_strategy :: Maybe TruncationStrategy
- tool_choice :: ToolChoice
- parallel_tool_calls :: Bool
- response_format :: AutoOr ResponseFormat
- data TruncationStrategy
- = Auto
- | Last_Messages { }
- data SubmitToolOutputs = SubmitToolOutputs {
- tool_calls :: Vector ToolCall
- data RequiredAction = RequiredAction_Submit_Tool_Outputs {}
- data IncompleteDetails = IncompleteDetails {}
- data ToolOutput = ToolOutput {
- tool_call_id :: Maybe Text
- output :: Text
- data Status
- type API = "threads" :> (Header' '[Required, Strict] "OpenAI-Beta" Text :> ((Capture "thread_id" ThreadID :> ("runs" :> (QueryParam "include[]" Text :> (ReqBody '[JSON] CreateRun :> Post '[JSON] RunObject)))) :<|> (("runs" :> (ReqBody '[JSON] CreateThreadAndRun :> Post '[JSON] RunObject)) :<|> ((Capture "thread_id" ThreadID :> ("runs" :> (QueryParam "limit" Natural :> (QueryParam "order" Order :> (QueryParam "after" Text :> (QueryParam "before" Text :> Get '[JSON] (ListOf RunObject))))))) :<|> ((Capture "thread_id" ThreadID :> ("runs" :> (Capture "run_id" RunID :> Get '[JSON] RunObject))) :<|> ((Capture "thread_id" ThreadID :> ("runs" :> (Capture "run_id" RunID :> (ReqBody '[JSON] ModifyRun :> Post '[JSON] RunObject)))) :<|> ((Capture "thread_id" ThreadID :> ("runs" :> (Capture "run_id" RunID :> ("submit_tool_outputs" :> (ReqBody '[JSON] SubmitToolOutputsToRun :> Post '[JSON] RunObject))))) :<|> (Capture "thread_id" ThreadID :> ("runs" :> (Capture "run_id" RunID :> ("cancel" :> Post '[JSON] RunObject)))))))))))
Main types
Run ID
Instances
| FromJSON RunID Source # | |
Defined in OpenAI.V1.Threads.Runs | |
| ToJSON RunID Source # | |
| IsString RunID Source # | |
Defined in OpenAI.V1.Threads.Runs Methods fromString :: String -> RunID # | |
| Show RunID Source # | |
| ToHttpApiData RunID Source # | |
Defined in OpenAI.V1.Threads.Runs Methods toUrlPiece :: RunID -> Text # toEncodedUrlPiece :: RunID -> Builder # toHeader :: RunID -> ByteString # toQueryParam :: RunID -> Text # toEncodedQueryParam :: RunID -> Builder # | |
Request body for /v1/threads/:thread_id/runs
Constructors
| CreateRun | |
Fields
| |
Instances
_CreateRun :: CreateRun Source #
Default CreateRun
data CreateThreadAndRun Source #
Request body for /v1/threads/runs
Constructors
| CreateThreadAndRun | |
Fields
| |
Instances
| FromJSON CreateThreadAndRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods parseJSON :: Value -> Parser CreateThreadAndRun # parseJSONList :: Value -> Parser [CreateThreadAndRun] # | |||||
| ToJSON CreateThreadAndRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods toJSON :: CreateThreadAndRun -> Value # toEncoding :: CreateThreadAndRun -> Encoding # toJSONList :: [CreateThreadAndRun] -> Value # toEncodingList :: [CreateThreadAndRun] -> Encoding # omitField :: CreateThreadAndRun -> Bool # | |||||
| Generic CreateThreadAndRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
Methods from :: CreateThreadAndRun -> Rep CreateThreadAndRun x # to :: Rep CreateThreadAndRun x -> CreateThreadAndRun # | |||||
| Show CreateThreadAndRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods showsPrec :: Int -> CreateThreadAndRun -> ShowS # show :: CreateThreadAndRun -> String # showList :: [CreateThreadAndRun] -> ShowS # | |||||
| type Rep CreateThreadAndRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep CreateThreadAndRun = D1 ('MetaData "CreateThreadAndRun" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "CreateThreadAndRun" 'PrefixI 'True) (((S1 ('MetaSel ('Just "assistant_id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 AssistantID) :*: (S1 ('MetaSel ('Just "thread") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Thread)) :*: S1 ('MetaSel ('Just "model") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Model)))) :*: ((S1 ('MetaSel ('Just "instructions") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "tools") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Vector Tool)))) :*: (S1 ('MetaSel ('Just "toolResources") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe ToolResources)) :*: S1 ('MetaSel ('Just "metadata") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Text)))))) :*: (((S1 ('MetaSel ('Just "temperature") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "top_p") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Double))) :*: (S1 ('MetaSel ('Just "max_prompt_tokens") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)) :*: S1 ('MetaSel ('Just "max_completion_tokens") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)))) :*: ((S1 ('MetaSel ('Just "truncation_strategy") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe TruncationStrategy)) :*: S1 ('MetaSel ('Just "tool_choice") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe ToolChoice))) :*: (S1 ('MetaSel ('Just "parallel_tool_calls") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Bool)) :*: S1 ('MetaSel ('Just "response_format") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (AutoOr ResponseFormat)))))))) | |||||
Request body for /v1/threads/:thread_id/runs/:run_id
Instances
| FromJSON ModifyRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs | |||||
| ToJSON ModifyRun Source # | |||||
| Generic ModifyRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
| |||||
| Show ModifyRun Source # | |||||
| type Rep ModifyRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs | |||||
_ModifyRun :: ModifyRun Source #
Default ModifyRun
data SubmitToolOutputsToRun Source #
Request body for /v1/threads/:thread_id/runs/:run_id/submit_tool_outputs
Constructors
| SubmitToolOutputsToRun | |
Fields
| |
Instances
| FromJSON SubmitToolOutputsToRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods parseJSON :: Value -> Parser SubmitToolOutputsToRun # parseJSONList :: Value -> Parser [SubmitToolOutputsToRun] # | |||||
| ToJSON SubmitToolOutputsToRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods toJSON :: SubmitToolOutputsToRun -> Value # toEncoding :: SubmitToolOutputsToRun -> Encoding # toJSONList :: [SubmitToolOutputsToRun] -> Value # toEncodingList :: [SubmitToolOutputsToRun] -> Encoding # omitField :: SubmitToolOutputsToRun -> Bool # | |||||
| Generic SubmitToolOutputsToRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
Methods from :: SubmitToolOutputsToRun -> Rep SubmitToolOutputsToRun x # to :: Rep SubmitToolOutputsToRun x -> SubmitToolOutputsToRun # | |||||
| Show SubmitToolOutputsToRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods showsPrec :: Int -> SubmitToolOutputsToRun -> ShowS # show :: SubmitToolOutputsToRun -> String # showList :: [SubmitToolOutputsToRun] -> ShowS # | |||||
| type Rep SubmitToolOutputsToRun Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep SubmitToolOutputsToRun = D1 ('MetaData "SubmitToolOutputsToRun" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "SubmitToolOutputsToRun" 'PrefixI 'True) (S1 ('MetaSel ('Just "tool_outputs") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Vector ToolOutput)))) | |||||
_SubmitToolOutputsToRun :: SubmitToolOutputsToRun Source #
Default implementation of SubmitToolOutputsToRun
Represents an execution run on a thread.
Constructors
| RunObject | |
Fields
| |
Instances
| FromJSON RunObject Source # | |||||
Defined in OpenAI.V1.Threads.Runs | |||||
| ToJSON RunObject Source # | |||||
| Generic RunObject Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
| |||||
| Show RunObject Source # | |||||
| type Rep RunObject Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep RunObject = D1 ('MetaData "RunObject" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "RunObject" 'PrefixI 'True) ((((S1 ('MetaSel ('Just "id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 RunID) :*: (S1 ('MetaSel ('Just "object") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text) :*: S1 ('MetaSel ('Just "created_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 POSIXTime))) :*: (S1 ('MetaSel ('Just "thread_id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 ThreadID) :*: (S1 ('MetaSel ('Just "assistant_id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 AssistantID) :*: S1 ('MetaSel ('Just "status") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Status)))) :*: ((S1 ('MetaSel ('Just "required_action") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe RequiredAction)) :*: (S1 ('MetaSel ('Just "last_error") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Error)) :*: S1 ('MetaSel ('Just "expires_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe POSIXTime)))) :*: ((S1 ('MetaSel ('Just "started_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe POSIXTime)) :*: S1 ('MetaSel ('Just "cancelled_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe POSIXTime))) :*: (S1 ('MetaSel ('Just "failed_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe POSIXTime)) :*: S1 ('MetaSel ('Just "completed_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe POSIXTime)))))) :*: (((S1 ('MetaSel ('Just "incomplete_details") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe IncompleteDetails)) :*: (S1 ('MetaSel ('Just "model") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Model) :*: S1 ('MetaSel ('Just "instructions") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)))) :*: ((S1 ('MetaSel ('Just "tools") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Vector Tool)) :*: S1 ('MetaSel ('Just "metadata") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Map Text Text))) :*: (S1 ('MetaSel ('Just "usage") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Usage (Maybe CompletionTokensDetails) (Maybe PromptTokensDetails)))) :*: S1 ('MetaSel ('Just "temperature") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Double))))) :*: ((S1 ('MetaSel ('Just "top_p") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Double)) :*: (S1 ('MetaSel ('Just "max_prompt_tokens") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)) :*: S1 ('MetaSel ('Just "max_completion_tokens") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)))) :*: ((S1 ('MetaSel ('Just "truncation_strategy") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe TruncationStrategy)) :*: S1 ('MetaSel ('Just "tool_choice") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 ToolChoice)) :*: (S1 ('MetaSel ('Just "parallel_tool_calls") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Bool) :*: S1 ('MetaSel ('Just "response_format") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (AutoOr ResponseFormat)))))))) | |||||
Other types
data TruncationStrategy Source #
Controls for how a thread will be truncated prior to the run
Constructors
| Auto | |
| Last_Messages | |
Fields | |
Instances
| FromJSON TruncationStrategy Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods parseJSON :: Value -> Parser TruncationStrategy # parseJSONList :: Value -> Parser [TruncationStrategy] # | |||||
| ToJSON TruncationStrategy Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods toJSON :: TruncationStrategy -> Value # toEncoding :: TruncationStrategy -> Encoding # toJSONList :: [TruncationStrategy] -> Value # toEncodingList :: [TruncationStrategy] -> Encoding # omitField :: TruncationStrategy -> Bool # | |||||
| Generic TruncationStrategy Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
Methods from :: TruncationStrategy -> Rep TruncationStrategy x # to :: Rep TruncationStrategy x -> TruncationStrategy # | |||||
| Show TruncationStrategy Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods showsPrec :: Int -> TruncationStrategy -> ShowS # show :: TruncationStrategy -> String # showList :: [TruncationStrategy] -> ShowS # | |||||
| type Rep TruncationStrategy Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep TruncationStrategy = D1 ('MetaData "TruncationStrategy" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "Auto" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "Last_Messages" 'PrefixI 'True) (S1 ('MetaSel ('Just "last_messages") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)))) | |||||
data SubmitToolOutputs Source #
Details on the tool outputs needed for this run to continue.
Constructors
| SubmitToolOutputs | |
Fields
| |
Instances
| FromJSON SubmitToolOutputs Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods parseJSON :: Value -> Parser SubmitToolOutputs # parseJSONList :: Value -> Parser [SubmitToolOutputs] # | |||||
| ToJSON SubmitToolOutputs Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods toJSON :: SubmitToolOutputs -> Value # toEncoding :: SubmitToolOutputs -> Encoding # toJSONList :: [SubmitToolOutputs] -> Value # toEncodingList :: [SubmitToolOutputs] -> Encoding # omitField :: SubmitToolOutputs -> Bool # | |||||
| Generic SubmitToolOutputs Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
Methods from :: SubmitToolOutputs -> Rep SubmitToolOutputs x # to :: Rep SubmitToolOutputs x -> SubmitToolOutputs # | |||||
| Show SubmitToolOutputs Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods showsPrec :: Int -> SubmitToolOutputs -> ShowS # show :: SubmitToolOutputs -> String # showList :: [SubmitToolOutputs] -> ShowS # | |||||
| type Rep SubmitToolOutputs Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep SubmitToolOutputs = D1 ('MetaData "SubmitToolOutputs" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "SubmitToolOutputs" 'PrefixI 'True) (S1 ('MetaSel ('Just "tool_calls") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Vector ToolCall)))) | |||||
data RequiredAction Source #
Details on the action required to continue the run
Constructors
| RequiredAction_Submit_Tool_Outputs | |
Fields | |
Instances
| FromJSON RequiredAction Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods parseJSON :: Value -> Parser RequiredAction # parseJSONList :: Value -> Parser [RequiredAction] # | |||||
| ToJSON RequiredAction Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods toJSON :: RequiredAction -> Value # toEncoding :: RequiredAction -> Encoding # toJSONList :: [RequiredAction] -> Value # toEncodingList :: [RequiredAction] -> Encoding # omitField :: RequiredAction -> Bool # | |||||
| Generic RequiredAction Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
Methods from :: RequiredAction -> Rep RequiredAction x # to :: Rep RequiredAction x -> RequiredAction # | |||||
| Show RequiredAction Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods showsPrec :: Int -> RequiredAction -> ShowS # show :: RequiredAction -> String # showList :: [RequiredAction] -> ShowS # | |||||
| type Rep RequiredAction Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep RequiredAction = D1 ('MetaData "RequiredAction" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "RequiredAction_Submit_Tool_Outputs" 'PrefixI 'True) (S1 ('MetaSel ('Just "submit_tool_outputs") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 SubmitToolOutputs))) | |||||
data IncompleteDetails Source #
Details on why the run is incomplete
Constructors
| IncompleteDetails | |
Instances
| FromJSON IncompleteDetails Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods parseJSON :: Value -> Parser IncompleteDetails # parseJSONList :: Value -> Parser [IncompleteDetails] # | |||||
| ToJSON IncompleteDetails Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods toJSON :: IncompleteDetails -> Value # toEncoding :: IncompleteDetails -> Encoding # toJSONList :: [IncompleteDetails] -> Value # toEncodingList :: [IncompleteDetails] -> Encoding # omitField :: IncompleteDetails -> Bool # | |||||
| Generic IncompleteDetails Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
Methods from :: IncompleteDetails -> Rep IncompleteDetails x # to :: Rep IncompleteDetails x -> IncompleteDetails # | |||||
| Show IncompleteDetails Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods showsPrec :: Int -> IncompleteDetails -> ShowS # show :: IncompleteDetails -> String # showList :: [IncompleteDetails] -> ShowS # | |||||
| type Rep IncompleteDetails Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep IncompleteDetails = D1 ('MetaData "IncompleteDetails" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "IncompleteDetails" 'PrefixI 'True) (S1 ('MetaSel ('Just "reason") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |||||
data ToolOutput Source #
A tool for which the output is being submitted
Constructors
| ToolOutput | |
Fields
| |
Instances
| FromJSON ToolOutput Source # | |||||
Defined in OpenAI.V1.Threads.Runs | |||||
| ToJSON ToolOutput Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods toJSON :: ToolOutput -> Value # toEncoding :: ToolOutput -> Encoding # toJSONList :: [ToolOutput] -> Value # toEncodingList :: [ToolOutput] -> Encoding # omitField :: ToolOutput -> Bool # | |||||
| Generic ToolOutput Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
| |||||
| Show ToolOutput Source # | |||||
Defined in OpenAI.V1.Threads.Runs Methods showsPrec :: Int -> ToolOutput -> ShowS # show :: ToolOutput -> String # showList :: [ToolOutput] -> ShowS # | |||||
| type Rep ToolOutput Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep ToolOutput = D1 ('MetaData "ToolOutput" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "ToolOutput" 'PrefixI 'True) (S1 ('MetaSel ('Just "tool_call_id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "output") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |||||
The status of the run
Constructors
| Queued | |
| In_Progress | |
| Requires_Action | |
| Cancelling | |
| Cancelled | |
| Failed | |
| Completed | |
| Incomplete | |
| Expired |
Instances
| FromJSON Status Source # | |||||
Defined in OpenAI.V1.Threads.Runs | |||||
| ToJSON Status Source # | |||||
| Generic Status Source # | |||||
Defined in OpenAI.V1.Threads.Runs Associated Types
| |||||
| Show Status Source # | |||||
| type Rep Status Source # | |||||
Defined in OpenAI.V1.Threads.Runs type Rep Status = D1 ('MetaData "Status" "OpenAI.V1.Threads.Runs" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (((C1 ('MetaCons "Queued" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "In_Progress" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "Requires_Action" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "Cancelling" 'PrefixI 'False) (U1 :: Type -> Type))) :+: ((C1 ('MetaCons "Cancelled" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "Failed" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "Completed" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "Incomplete" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "Expired" 'PrefixI 'False) (U1 :: Type -> Type))))) | |||||
Servant
type API = "threads" :> (Header' '[Required, Strict] "OpenAI-Beta" Text :> ((Capture "thread_id" ThreadID :> ("runs" :> (QueryParam "include[]" Text :> (ReqBody '[JSON] CreateRun :> Post '[JSON] RunObject)))) :<|> (("runs" :> (ReqBody '[JSON] CreateThreadAndRun :> Post '[JSON] RunObject)) :<|> ((Capture "thread_id" ThreadID :> ("runs" :> (QueryParam "limit" Natural :> (QueryParam "order" Order :> (QueryParam "after" Text :> (QueryParam "before" Text :> Get '[JSON] (ListOf RunObject))))))) :<|> ((Capture "thread_id" ThreadID :> ("runs" :> (Capture "run_id" RunID :> Get '[JSON] RunObject))) :<|> ((Capture "thread_id" ThreadID :> ("runs" :> (Capture "run_id" RunID :> (ReqBody '[JSON] ModifyRun :> Post '[JSON] RunObject)))) :<|> ((Capture "thread_id" ThreadID :> ("runs" :> (Capture "run_id" RunID :> ("submit_tool_outputs" :> (ReqBody '[JSON] SubmitToolOutputsToRun :> Post '[JSON] RunObject))))) :<|> (Capture "thread_id" ThreadID :> ("runs" :> (Capture "run_id" RunID :> ("cancel" :> Post '[JSON] RunObject))))))))))) Source #
Servant API