| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.ToolResources
Contents
Description
The ToolResources type
Synopsis
- data ToolResources = ToolResources {}
- data CodeInterpreterResources = CodeInterpreterResources {}
- data Static = Static {}
- data VectorStore = VectorStore {
- file_ids :: Maybe (Vector FileID)
- chunking_strategy :: Maybe (AutoOr ChunkingStrategy)
- data FileSearchResources = FileSearchResources {
- vector_store_ids :: Maybe (Vector FileID)
- vector_stores :: Maybe (Vector VectorStore)
Main types
data ToolResources Source #
A set of resources that are used by the assistant's tools
Constructors
| ToolResources | |
Instances
Other types
data CodeInterpreterResources Source #
Resources for the code search tool
Constructors
| CodeInterpreterResources | |
Instances
| FromJSON CodeInterpreterResources Source # | |||||
Defined in OpenAI.V1.ToolResources Methods parseJSON :: Value -> Parser CodeInterpreterResources # parseJSONList :: Value -> Parser [CodeInterpreterResources] # | |||||
| ToJSON CodeInterpreterResources Source # | |||||
Defined in OpenAI.V1.ToolResources Methods toJSON :: CodeInterpreterResources -> Value # toEncoding :: CodeInterpreterResources -> Encoding # toJSONList :: [CodeInterpreterResources] -> Value # | |||||
| Generic CodeInterpreterResources Source # | |||||
Defined in OpenAI.V1.ToolResources Associated Types
Methods from :: CodeInterpreterResources -> Rep CodeInterpreterResources x # to :: Rep CodeInterpreterResources x -> CodeInterpreterResources # | |||||
| Show CodeInterpreterResources Source # | |||||
Defined in OpenAI.V1.ToolResources Methods showsPrec :: Int -> CodeInterpreterResources -> ShowS # show :: CodeInterpreterResources -> String # showList :: [CodeInterpreterResources] -> ShowS # | |||||
| type Rep CodeInterpreterResources Source # | |||||
Defined in OpenAI.V1.ToolResources type Rep CodeInterpreterResources = D1 ('MetaData "CodeInterpreterResources" "OpenAI.V1.ToolResources" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "CodeInterpreterResources" 'PrefixI 'True) (S1 ('MetaSel ('Just "file_ids") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Vector FileID))))) | |||||
Static chunking strategy
Constructors
| Static | |
Fields | |
Instances
| FromJSON Static Source # | |||||
Defined in OpenAI.V1.ChunkingStrategy | |||||
| ToJSON Static Source # | |||||
| Generic Static Source # | |||||
Defined in OpenAI.V1.ChunkingStrategy Associated Types
| |||||
| Show Static Source # | |||||
| type Rep Static Source # | |||||
Defined in OpenAI.V1.ChunkingStrategy type Rep Static = D1 ('MetaData "Static" "OpenAI.V1.ChunkingStrategy" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "Static" 'PrefixI 'True) (S1 ('MetaSel ('Just "max_chunk_size_tokens") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Natural) :*: S1 ('MetaSel ('Just "chunk_overlap_tokens") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Natural))) | |||||
data VectorStore Source #
A helper to create a vector store with file_ids and attach it to this assistant
Constructors
| VectorStore | |
Fields
| |
Instances
| FromJSON VectorStore Source # | |||||
Defined in OpenAI.V1.ToolResources | |||||
| ToJSON VectorStore Source # | |||||
Defined in OpenAI.V1.ToolResources Methods toJSON :: VectorStore -> Value # toEncoding :: VectorStore -> Encoding # toJSONList :: [VectorStore] -> Value # toEncodingList :: [VectorStore] -> Encoding # omitField :: VectorStore -> Bool # | |||||
| Generic VectorStore Source # | |||||
Defined in OpenAI.V1.ToolResources Associated Types
| |||||
| Show VectorStore Source # | |||||
Defined in OpenAI.V1.ToolResources Methods showsPrec :: Int -> VectorStore -> ShowS # show :: VectorStore -> String # showList :: [VectorStore] -> ShowS # | |||||
| type Rep VectorStore Source # | |||||
Defined in OpenAI.V1.ToolResources type Rep VectorStore = D1 ('MetaData "VectorStore" "OpenAI.V1.ToolResources" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "VectorStore" 'PrefixI 'True) (S1 ('MetaSel ('Just "file_ids") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Vector FileID))) :*: S1 ('MetaSel ('Just "chunking_strategy") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (AutoOr ChunkingStrategy))))) | |||||
data FileSearchResources Source #
Resources for the file search tool
Constructors
| FileSearchResources | |
Fields
| |
Instances
| FromJSON FileSearchResources Source # | |||||
Defined in OpenAI.V1.ToolResources Methods parseJSON :: Value -> Parser FileSearchResources # parseJSONList :: Value -> Parser [FileSearchResources] # | |||||
| ToJSON FileSearchResources Source # | |||||
Defined in OpenAI.V1.ToolResources Methods toJSON :: FileSearchResources -> Value # toEncoding :: FileSearchResources -> Encoding # toJSONList :: [FileSearchResources] -> Value # toEncodingList :: [FileSearchResources] -> Encoding # omitField :: FileSearchResources -> Bool # | |||||
| Generic FileSearchResources Source # | |||||
Defined in OpenAI.V1.ToolResources Associated Types
Methods from :: FileSearchResources -> Rep FileSearchResources x # to :: Rep FileSearchResources x -> FileSearchResources # | |||||
| Show FileSearchResources Source # | |||||
Defined in OpenAI.V1.ToolResources Methods showsPrec :: Int -> FileSearchResources -> ShowS # show :: FileSearchResources -> String # showList :: [FileSearchResources] -> ShowS # | |||||
| type Rep FileSearchResources Source # | |||||
Defined in OpenAI.V1.ToolResources type Rep FileSearchResources = D1 ('MetaData "FileSearchResources" "OpenAI.V1.ToolResources" "openai-2.2.1-FjXYHvgDuLi5dBzIG7AGPx" 'False) (C1 ('MetaCons "FileSearchResources" 'PrefixI 'True) (S1 ('MetaSel ('Just "vector_store_ids") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Vector FileID))) :*: S1 ('MetaSel ('Just "vector_stores") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Vector VectorStore))))) | |||||