| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenAI.V1.Error
Contents
Description
Error information
Types
More information on the cause of the failure.
NOTE: OpenAPI API's says that the code and message fields are required,
but in practice the Error record can be present with all fields omitted,
so they are all marked optional (Maybe) here
Constructors
| Error | |